compute_quantitative_accuracy: Compute Quantitative Accuracy Score

Description Usage Arguments Details Value

Description

Each n-of-1 mutation signature method computes the exposure of each signature (its contribution to the mutation burden). These numeric outcomes are stored in the "exposure" column of the calculated_exposures table in simulated data output. In order to evaluate each method's accuracy at assigning exposure values, this method uses various distance metrics to compare the true signatures which gave rise to a simulated mutation with the reconstructed signatures estimated by the signature method.

Usage

1

Arguments

simulated_data

The data object output by simulate_samples() with exposures calculated using one of the signature exposure calculation methods.

Details

The metrics reported are L2 normalized Euclidean distance and cosine distance. In L2 normalized Euclidean distance, the exposure vectors \mathbf{x}, \mathbf{y} are normalized as in \mathbf{x'} = frac{\mathbf{x}}{\lVert \mathbf{x} \rVert} into unit vectors. Then the Euclidean distance \lVert \mathbf{y'} - \mathbf{x'} \rVert is computed.

The cosine distance is calculated as 1 - \frac{\mathbf{x} \cdot \mathbf{y}}{\lVert \mathbf{x} \rVert \lVert \mathbf{y} \rVert}.

Value

A list with named items that report the distance metrics.


eyzhao/msimR documentation built on June 6, 2019, 7:53 a.m.